==> quasar-1.8.5.jar: META-INF/resources/webjars/quasar/1.8.5/icon-set/material-icons-outlined.js <==
export default {
  name: 'material-icons-outlined',
  type: {
    positive: 'o_check_circle',
    negative: 'o_warning',
    info: 'o_info',
    warning: 'o_priority_high'
  },
  arrow: {
    up: 'o_arrow_upward',
    right: 'o_arrow_forward',
    down: 'o_arrow_downward',
    left: 'o_arrow_back',
    dropdown: 'o_arrow_drop_down'
  },
  chevron: {
    left: 'o_chevron_left',
    right: 'o_chevron_right'
  },
  colorPicker: {
    spectrum: 'o_gradient',
    tune: 'o_tune',
    palette: 'o_style'
  },
  pullToRefresh: {
    icon: 'o_refresh'
  },
  carousel: {
    left: 'o_chevron_left',
    right: 'o_chevron_right',
    navigationIcon: 'o_lens',
    thumbnails: 'o_view_carousel'
  },
  chip: {
    remove: 'o_cancel',
    selected: 'o_check'
  },
  datetime: {
    arrowLeft: 'o_chevron_left',
    arrowRight: 'o_chevron_right',
    now: 'o_access_time',
    today: 'o_today'
  },
  editor: {
    bold: 'o_format_bold',
    italic: 'o_format_italic',
    strikethrough: 'o_strikethrough_s',
    underline: 'o_format_underlined',
    unorderedList: 'o_format_list_bulleted',
    orderedList: 'o_format_list_numbered',
    subscript: 'o_vertical_align_bottom',
    superscript: 'o_vertical_align_top',
    hyperlink: 'o_link',
    toggleFullscreen: 'o_fullscreen',
    quote: 'o_format_quote',
    left: 'o_format_align_left',
    center: 'o_format_align_center',
    right: 'o_format_align_right',
    justify: 'o_format_align_justify',
    print: 'o_print',
    outdent: 'o_format_indent_decrease',
    indent: 'o_format_indent_increase',
    removeFormat: 'o_format_clear',
    formatting: 'o_text_format',
    fontSize: 'o_format_size',
    align: 'o_format_align_left',
    hr: 'o_remove',
    undo: 'o_undo',
    redo: 'o_redo',
    heading: 'o_format_size',
    code: 'o_code',
    size: 'o_format_size',
    font: 'o_font_download',
    viewSource: 'o_code'
  },
  expansionItem: {
    icon: 'o_keyboard_arrow_down',
    denseIcon: 'o_arrow_drop_down'
  },
  fab: {
    icon: 'o_add',
    activeIcon: 'o_close'
  },
  field: {
    clear: 'o_cancel',
    error: 'o_error'
  },
  pagination: {
    first: 'o_first_page',
    prev: 'o_keyboard_arrow_left',
    next: 'o_keyboard_arrow_right',
    last: 'o_last_page'
  },
  rating: {
    icon: 'o_grade'
  },
  stepper: {
    done: 'o_check',
    active: 'o_edit',
    error: 'o_warning'
  },
  tabs: {
    left: 'o_chevron_left',
    right: 'o_chevron_right',
    up: 'o_keyboard_arrow_up',
    down: 'o_keyboard_arrow_down'
  },
  table: {
    arrowUp: 'o_arrow_upward',
    warning: 'o_warning',
    prevPage: 'o_chevron_left',
    nextPage: 'o_chevron_right'
  },
  tree: {
    icon: 'o_play_arrow'
  },
  uploader: {
    done: 'o_done',
    clear: 'o_clear',
    add: 'o_add_box',
    upload: 'o_cloud_upload',
    removeQueue: 'o_clear_all',
    removeUploaded: 'o_done_all'
  }
}

==> quasar-1.9.16.jar: META-INF/resources/webjars/quasar/1.9.16/icon-set/material-icons-outlined.js <==
export default {
  name: 'material-icons-outlined',
  type: {
    positive: 'o_check_circle',
    negative: 'o_warning',
    info: 'o_info',
    warning: 'o_priority_high'
  },
  arrow: {
    up: 'o_arrow_upward',
    right: 'o_arrow_forward',
    down: 'o_arrow_downward',
    left: 'o_arrow_back',
    dropdown: 'o_arrow_drop_down'
  },
  chevron: {
    left: 'o_chevron_left',
    right: 'o_chevron_right'
  },
  colorPicker: {
    spectrum: 'o_gradient',
    tune: 'o_tune',
    palette: 'o_style'
  },
  pullToRefresh: {
    icon: 'o_refresh'
  },
  carousel: {
    left: 'o_chevron_left',
    right: 'o_chevron_right',
    up: 'o_keyboard_arrow_up',
    down: 'o_keyboard_arrow_down',
    navigationIcon: 'o_lens'
  },
  chip: {
    remove: 'o_cancel',
    selected: 'o_check'
  },
  datetime: {
    arrowLeft: 'o_chevron_left',
    arrowRight: 'o_chevron_right',
    now: 'o_access_time',
    today: 'o_today'
  },
  editor: {
    bold: 'o_format_bold',
    italic: 'o_format_italic',
    strikethrough: 'o_strikethrough_s',
    underline: 'o_format_underlined',
    unorderedList: 'o_format_list_bulleted',
    orderedList: 'o_format_list_numbered',
    subscript: 'o_vertical_align_bottom',
    superscript: 'o_vertical_align_top',
    hyperlink: 'o_link',
    toggleFullscreen: 'o_fullscreen',
    quote: 'o_format_quote',
    left: 'o_format_align_left',
    center: 'o_format_align_center',
    right: 'o_format_align_right',
    justify: 'o_format_align_justify',
    print: 'o_print',
    outdent: 'o_format_indent_decrease',
    indent: 'o_format_indent_increase',
    removeFormat: 'o_format_clear',
    formatting: 'o_text_format',
    fontSize: 'o_format_size',
    align: 'o_format_align_left',
    hr: 'o_remove',
    undo: 'o_undo',
    redo: 'o_redo',
    heading: 'o_format_size',
    code: 'o_code',
    size: 'o_format_size',
    font: 'o_font_download',
    viewSource: 'o_code'
  },
  expansionItem: {
    icon: 'o_keyboard_arrow_down',
    denseIcon: 'o_arrow_drop_down'
  },
  fab: {
    icon: 'o_add',
    activeIcon: 'o_close'
  },
  field: {
    clear: 'o_cancel',
    error: 'o_error'
  },
  pagination: {
    first: 'o_first_page',
    prev: 'o_keyboard_arrow_left',
    next: 'o_keyboard_arrow_right',
    last: 'o_last_page'
  },
  rating: {
    icon: 'o_grade'
  },
  stepper: {
    done: 'o_check',
    active: 'o_edit',
    error: 'o_warning'
  },
  tabs: {
    left: 'o_chevron_left',
    right: 'o_chevron_right',
    up: 'o_keyboard_arrow_up',
    down: 'o_keyboard_arrow_down'
  },
  table: {
    arrowUp: 'o_arrow_upward',
    warning: 'o_warning',
    prevPage: 'o_chevron_left',
    nextPage: 'o_chevron_right'
  },
  tree: {
    icon: 'o_play_arrow'
  },
  uploader: {
    done: 'o_done',
    clear: 'o_clear',
    add: 'o_add_box',
    upload: 'o_cloud_upload',
    removeQueue: 'o_clear_all',
    removeUploaded: 'o_done_all'
  }
}
